*************************************************************
* REPLICATION CODE FOR SECTION ON PYTHON INTEGRATION
* 	Copyright 2020 Ho, Huynh, Jacho and Rojas
* Author: Ho, Huynh, Jacho and Rojas
* Purpose: Illustrate the integration of Stata 16 with
*	python through the module SFI
*
* Important: To run this code user must possess a licence of
*      Stata 16. You need to have local installation of Python 3.
*	Also,  all required modules should be 
*      should be installed in your local Python installation.
*
* Windows users: To run this code with a Anaconda installation 
*	you need to make sure that the QT-plugin is correctly 
*	linked by typing on your Stata command prompt
* 	 	
*   		python
*   		import os
*    		os.environ['QT_QPA_PLATFORM_PLUGIN_PATH'] = #"Your\\path\\to\\Anaconda3\\Library\\plugins"
*    		end
*
*************************************************************



sysuse auto

python



from sfi import *
import pandas as pd
import numpy as np
from sklearn.cluster import KMeans
from sklearn.preprocessing import StandardScaler
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D

f=Frame.connect("default")
m=pd.DataFrame.from_dict( f.getAsDict(["mpg","weight","price"]))

for var in list(m): m[var] = m[var].astype(float)

X = StandardScaler().fit_transform(m)

k=KMeans(n_clusters=4, random_state=0).fit(X)

fig = plt.figure(figsize=(12,10))
ax = fig.add_subplot(111, projection='3d')
ax.scatter(m["mpg"],m["weight"],m["price"],
            c=k.labels_, cmap='viridis',
            edgecolor='k', s=40, alpha = 0.8)


ax.set_title("Cars clustering")

ax.set_xlabel("Miles_per_gallon")

ax.set_ylabel("Weight")

ax.set_zlabel("Price")

ax.dist = 10
plt.autoscale(enable=True, axis='x', tight=True)
plt.show()
end

/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
